@@ -8,8 +8,8 @@ class BootpayBackend:
         'stage': 'https://stage-api.bootpay.co.kr/v2',
         'production': 'https://api.bootpay.co.kr/v2'
     }
-    API_VERSION = '4.2.0'
-    SDK_VERSION = '2.0.5'
+    API_VERSION = '4.2.9'
+    SDK_VERSION = '2.0.7'
 
     def __init__(self, application_id, private_key, mode='production'):
         self.application_id = application_id
@@ -140,12 +140,13 @@ class BootpayBackend:
 
     # subscribe payment reserve
     # Comment by GOSOMI
-    def subscribe_payment_reserve(self, billing_key='', order_name='', price=0, tax_free=0, order_id='', items=None,
+    def subscribe_payment_reserve(self, billing_key='', order_name='', price=0, tax_free=0, order_id='', items=None, metadata={},
                                   user=None, reserve_execute_at='', feedback_url='', content_type=''):
         return self.__request(method='post', url=self.__entrypoints('subscribe/payment/reserve'), data={
             "billing_key": billing_key,
             "order_name": order_name,
             "price": price,
+            "metadata": metadata,
             "tax_free": tax_free,
             "order_id": order_id,
             "items": items,
@@ -156,10 +157,11 @@ class BootpayBackend:
         })
 
     def cancel_payment(self, receipt_id='', cancel_id='', cancel_username='', cancel_message='', cancel_price=None,
-                       cancel_tax_free=None, refund=None, items=None):
+                       metadata={}, cancel_tax_free=None, refund=None, items=None):
         return self.__request(method='post', url=self.__entrypoints('cancel'), data={
             "receipt_id": receipt_id,
             "cancel_id": cancel_id,
+            "metadata": metadata,
             "cancel_username": cancel_username,
             "cancel_message": cancel_message,
             "cancel_price": cancel_price,
@@ -168,6 +170,12 @@ class BootpayBackend:
             "items": items
         })
 
+    # subscribe payment reserve lookup
+    # Comment by GOSOMI
+    # @date: 2023-03-08
+    def subscribe_payment_reserve_lookup(self, reserve_id=''):
+        return self.__request(method='get', url=self.__entrypoints(f'subscribe/payment/reserve/{reserve_id}'))
+
     # cancel subscribe reserve
     # Comment by GOSOMI
     def cancel_subscribe_reserve(self, reserve_id=''):
@@ -248,3 +256,52 @@ class BootpayBackend:
                 "cancel_message": cancel_message
             })
         )
+
+    # 본인인증 REST API 요청
+    # Comment by GOSOMI
+    # @date: 2022-11-07
+    def request_authentication(self, pg='', method='', username='', identity_no='', carrier='', phone='', site_url='',
+                               order_name='', authentication_id='', authenticate_type='sms', user=None, extra={}):
+        return self.__request(
+            method='post',
+            url=self.__entrypoints('request/authentication'),
+            data={
+                "pg": pg,
+                "method": method,
+                "authentication_id": authentication_id,
+                "authenticate_type": authenticate_type,
+                "username": username,
+                "identity_no": identity_no,
+                "carrier": carrier,
+                "phone": phone,
+                "site_url": site_url,
+                "order_name": order_name,
+                "user": user,
+                "extra": extra
+            }
+        )
+
+    # 본인인증 승인 REST API
+    # Comment by GOSOMI
+    # @date: 2022-11-07
+    def confirm_authentication(self, receipt_id='', otp=''):
+        return self.__request(
+            method='post',
+            url=self.__entrypoints('authenticate/confirm'),
+            data={
+                "receipt_id": receipt_id,
+                "otp": otp
+            }
+        )
+
+    # SMS로 본인인증 요청시 SMS 재발송 로직
+    # Comment by GOSOMI
+    # @date: 2022-11-07
+    def realarm_authentication(self, receipt_id=''):
+        return self.__request(
+            method='post',
+            url=self.__entrypoints('authenticate/realarm'),
+            data={
+                "receipt_id": receipt_id
+            }
+        )
